package de.juplo.demo;


import java.util.HashMap;
import java.util.Map;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;


/**
 *
 * @author Kai Moritz
 */
@Controller
public class DemoController
{
  private static final Logger LOG =
      LoggerFactory.getLogger(DemoController.class);


  @RequestMapping("/")
  public String display(@ModelAttribute Form form)
  {
    for (Integer id : form.cards.keySet())
      for (String entry : form.cards.get(id).keySet())
        LOG.info("{} - {}: {}", id, entry, form.cards.get(id).get(entry));

    return "form";
  }

  @RequestMapping(path = "/", params = "add=card")
  public String addCard(@ModelAttribute Form form)
  {
    Integer next =
        form.cards
            .keySet()
            .stream()
            .reduce(0, (a, b) -> a > b ? a : b) + 1;

    LOG.info("Adding new card #{}", next);
    form.cards.put(next, new HashMap<>());
    return "form";
  }

  @RequestMapping(path = "/", params = "remove=card")
  public String removeCard(
      @ModelAttribute Form form,
      @RequestParam Integer card)
  {
    Map<String, Boolean> content = form.cards.remove(card);
    LOG.info("Removed card #{} with content: {}", card, content);
    return "form";
  }

  @RequestMapping(path = "/", params = "add=row")
  public String addRow(@ModelAttribute Form form, @RequestParam Integer card)
  {
    LOG.info("Adding row {} to card #{}", form.row.get(card), card);
    form.cards.get(card).put(form.row.get(card), Boolean.FALSE);
    return "form";
  }

  @RequestMapping(path = "/", params = "remove!=card")
  public String removeRow(@ModelAttribute Form form, @RequestParam String remove)
  {
    String[] parts = remove.split(":", 2);
    Integer card = Integer.valueOf(parts[0]);
    String row = parts[1];
    Boolean value = form.cards.get(card).remove(row);
    LOG.info("Removed row {} with value {} from card #{}", row, value, card);
    return "form";
  }
}
